==> firefox-22.0.source.tar.bz2: mozilla-release/addon-sdk/source/doc/dev-guide-source/credits.md <==
<!-- This Source Code Form is subject to the terms of the Mozilla Public
   - License, v. 2.0. If a copy of the MPL was not distributed with this
   - file, You can obtain one at http://mozilla.org/MPL/2.0/. -->

# Credits #

We'd like to thank our many Jetpack project contributors!  They include:

### A ###

* Adamantium
* Ehsan Akhgari
* arky
* [Heather Arthur](https://github.com/harthur)
* Dietrich Ayala

<!--end-->

### B ###

* [Romain B](https://github.com/Niamor)
* [Louis-Rémi Babé](https://github.com/louisremi)
* Will Bamberg
* Thomas Bassetto
* Tomaz Bevec
* Zbigniew Braniecki
* Daniel Buchner
* James Burke

<!--end-->

### C ###

* [Shane Caraveo](https://github.com/mixedpuppy)
* [Matěj Cepl](https://github.com/mcepl)
* Marc Chevrier
* Hernán Rodriguez Colmeiro
* [David Creswick](https://github.com/dcrewi)

<!--end-->

### D ###

* dexter
* Christopher Dorn
* Connor Dunn
* dynamis

<!--end-->

### F ###

* [Matteo Ferretti (ZER0)](https://github.com/ZER0)
* fuzzykiller

<!--end-->

### G ###

* [Marcio Galli](https://github.com/taboca)
* [Ben Gillbanks](http://www.iconfinder.com/browse/iconset/circular_icons/)
* Felipe Gomes
* Irakli Gozalishvili
* Luca Greco
* Jeff Griffiths
* [David Guo](https://github.com/dglol)

<!--end-->

### H ###

* Mark Hammond
* Mark A. Hershberger
* Lloyd Hilaiel
* Bobby Holley

<!--end-->

### I ###

* Shun Ikejima

<!--end-->

### J ###

* Eric H. Jung

<!--end-->

### K ###

* Hrishikesh Kale
* Wes Kocher
* Lajos Koszti
* [Vladimir Kukushkin](https://github.com/kukushechkin)

<!--end-->

### L ###

* Edward Lee
* Gregg Lind

<!--end-->

### M ###

* [Nils Maier](https://github.com/nmaier)
* Gervase Markham
* Dave Mason
* Myk Melez
* Zandr Milewski
* Noelle Murata

<!--end-->

### N ###

* Siavash Askari Nasr
* Joe R. Nassimian ([placidrage](https://github.com/placidrage))
* Dương H. Nguyễn
* Nick Nguyen

<!--end-->

### O ###

* [ongaeshi](https://github.com/ongaeshi)
* Paul O’Shannessy
* Les Orchard

<!--end-->

### P ###

* Robert Pankowecki
* [Jamie Phelps](https://github.com/jxpx777)
* [Alexandre Poirot](https://github.com/ochameau)
* Nickolay Ponomarev

<!--end-->

### R ###

* Aza Raskin

<!--end-->

### S ###

* Till Schneidereit
* Justin Scott
* Ayan Shah
* [skratchdot](https://github.com/skratchdot)
* Henrik Skupin
* slash
* Markus Stange
* Dan Stevens
* [Mihai Sucan](https://github.com/mihaisucan)

<!--end-->

### T ###

* taku0
* Clint Talbert
* Tim Taubert
* Shane Tomlinson
* Dave Townsend
* [Matthias Tylkowski](https://github.com/tylkomat)

<!--end-->

### V ###

* Peter Van der Beken
* Sander van Veen
* Atul Varma
* [Erik Vold](https://github.com/erikvold)
* Vladimir Vukicevic

<!--end-->

### W ###

* Brian Warner
* [Henri Wiechers](https://github.com/hwiechers)
* Drew Willcoxon
* Blake Winton
* Michal Wojciechowski

<!--end-->

### Z ###

* Piotr Zalewa
* Brett Zamir

==> firefox-25.0.source.tar.bz2: mozilla-release/addon-sdk/source/doc/dev-guide-source/credits.md <==
<!-- This Source Code Form is subject to the terms of the Mozilla Public
   - License, v. 2.0. If a copy of the MPL was not distributed with this
   - file, You can obtain one at http://mozilla.org/MPL/2.0/. -->

# Credits #

We'd like to thank our many Jetpack project contributors!  They include:

### A ###

* Adamantium
* Ehsan Akhgari
* arky
* [Heather Arthur](https://github.com/harthur)
* Dietrich Ayala

### B ###

* [Romain B](https://github.com/Niamor)
* [Louis-Rémi Babé](https://github.com/louisremi)
* Will Bamberg
* Thomas Bassetto
* Tomaz Bevec
* Zbigniew Braniecki
* Daniel Buchner
* James Burke

### C ###

* [Shane Caraveo](https://github.com/mixedpuppy)
* [Matěj Cepl](https://github.com/mcepl)
* Marc Chevrier
* [Timothy Guan-tin Chien](https://github.com/timdream)
* Hernán Rodriguez Colmeiro
* [David Creswick](https://github.com/dcrewi)

### D ###

* dexter
* Christopher Dorn
* Connor Dunn
* dynamis

### F ###

* [Corey Farwell](http://github.com/frewsxcv)
* [Matteo Ferretti](https://github.com/ZER0)
* fuzzykiller

### G ###

* [Marcio Galli](https://github.com/taboca)
* [Ben Gillbanks](http://www.iconfinder.com/browse/iconset/circular_icons/)
* Felipe Gomes
* Irakli Gozalishvili
* Luca Greco
* Jeff Griffiths
* [David Guo](https://github.com/dglol)

### H ###

* Mark Hammond
* Mark A. Hershberger
* Lloyd Hilaiel
* Bobby Holley

### I ###

* Shun Ikejima

### J ###

* Eric H. Jung

### K ###

* Hrishikesh Kale
* Wes Kocher
* Lajos Koszti
* Kusanagi Kouichi
* [Vladimir Kukushkin](https://github.com/kukushechkin)

### L ###

* Edward Lee
* Gregg Lind

### M ###

* [Nils Maier](https://github.com/nmaier)
* Gervase Markham
* Dave Mason
* Myk Melez
* Zandr Milewski
* Noelle Murata

### N ###

* Siavash Askari Nasr
* Joe R. Nassimian ([placidrage](https://github.com/placidrage))
* Dương H. Nguyễn
* Nick Nguyen

### O ###

* [ongaeshi](https://github.com/ongaeshi)
* Paul O’Shannessy
* Les Orchard

### P ###

* Robert Pankowecki
* [Jamie Phelps](https://github.com/jxpx777)
* [Alexandre Poirot](https://github.com/ochameau)
* Nickolay Ponomarev

### R ###

* Aza Raskin

### S ###

* [Jordan Santell](https://github.com/jsantell)
* Till Schneidereit
* Justin Scott
* Ayan Shah
* [skratchdot](https://github.com/skratchdot)
* Henrik Skupin
* slash
* Markus Stange
* Dan Stevens
* [J. Ryan Stinnett](https://github.com/jryans)
* [Mihai Sucan](https://github.com/mihaisucan)
* Sunny ([darkowlzz](https://github.com/darkowlzz))

### T ###

* taku0
* Clint Talbert
* Tim Taubert
* Shane Tomlinson
* Dave Townsend
* [Matthias Tylkowski](https://github.com/tylkomat)

### V ###

* Peter Van der Beken
* Sander van Veen
* Atul Varma
* [Erik Vold](https://github.com/erikvold)
* Vladimir Vukicevic

### W ###

* Brian Warner
* [Henri Wiechers](https://github.com/hwiechers)
* Drew Willcoxon
* Blake Winton
* Michal Wojciechowski

### Z ###

* Piotr Zalewa
* Brett Zamir
